import { Router } from "express";
import { body } from "express-validator";
import handleValidationResult from "../middleware/handleValidationResult";
import createLogEntryController from "../controllers/createLogEntry.controllers";

const entryRouter = Router();

//create new log entry route
entryRouter.post(
  "/api/logentry/",
  //isISO8601() checks if string is a valid date+time
  body("startTime").isISO8601(),
  body("estimatedEndTime").isISO8601(),
  body("destination").isString(),
  body("email").isEmail().normalizeEmail(),
  body("fullNameOfResponsibleClient").not().isEmpty(),
  body("boatId").isUUID(),
  body("additionalClients").if(body("additionalClients").exists()).isArray(),
  body("numP").isInt(), //number of the total participants (fullNameOfResponsibleClient + additionalClients)
  body("note").if(body("note").exists()).isString(),
  handleValidationResult,
  createLogEntryController
);

export default entryRouter;